@@ -12,7 +12,7 @@ use warnings;
 
 package Dist::Zilla::Plugin::CompileTests;
 BEGIN {
-  $Dist::Zilla::Plugin::CompileTests::VERSION = '1.110870';
+  $Dist::Zilla::Plugin::CompileTests::VERSION = '1.110930';
 }
 # ABSTRACT: common tests to check syntax of your modules
 
@@ -80,7 +80,7 @@ Dist::Zilla::Plugin::CompileTests - common tests to check syntax of your modules
 
 =head1 VERSION
 
-version 1.110870
+version 1.110930
 
 =head1 SYNOPSIS
 
@@ -195,15 +195,17 @@ find(
 );
 
 my @scripts;
-find(
-  sub {
-    return unless -f;
-    my $found = $File::Find::name;
-    COMPILETESTS_SKIP
-    push @scripts, $found;
-  },
-  'bin',
-);
+if ( -d 'bin' ) {
+    find(
+      sub {
+        return unless -f;
+        my $found = $File::Find::name;
+        COMPILETESTS_SKIP
+        push @scripts, $found;
+      },
+      'bin',
+    );
+}
 
 my $plan = scalar(@modules) + scalar(@scripts);
 $plan ? (plan tests => $plan) : (plan skip_all => "no tests to run");
